# ---------------------------------------------------------------------------
# Title: Set PCS State Plane
#    
# Description:  Sets the spatial reference of the current data frame to the
#               appropriate state plane projected coordinate system, based on
#               the current extent
#
# Written by: Adam Cox
# Last updated: 3-20-14
# ---------------------------------------------------------------------------

import arcpy, os, traceback, sys

a = os.path.dirname(os.path.dirname(sys.argv[0]))
data_dir = a + r"\data"

prjPath = data_dir + os.sep + "SP NAD 1983 (US Feet)"
shp = data_dir + os.sep + "usstpln83.shp"
lyr = "fl"

mxd = arcpy.mapping.MapDocument("CURRENT")
for d in arcpy.mapping.ListDataFrames(mxd):
    if d.name == mxd.activeView:
        df = d
try:

    dfAsFeature = arcpy.Polygon(arcpy.Array([df.extent.lowerLeft,
         df.extent.lowerRight, df.extent.upperRight, df.extent.upperLeft]),
                            df.spatialReference)
    arcpy.management.MakeFeatureLayer(shp, lyr)
    arcpy.SelectLayerByLocation_management(lyr, "INTERSECT",
                                           dfAsFeature, "", "NEW_SELECTION")
    if int(arcpy.management.GetCount(lyr).getOutput(0)) == 1:
        rows = arcpy.SearchCursor(lyr,"","","FIPSZONE83")
        for row in rows:
            z = str(row.getValue("FIPSZONE83"))
        if not len(z) == 4:
            zoneID = str((4 - len(z))*"0") + z
        else:
            zoneID = z
        for prj in os.listdir(prjPath):
            if zoneID in prj:
                prjFile = prjPath + os.sep + prj

        arcpy.AddMessage("\nSetting spatial reference to State Plane (NAD83, US Feet)...\n")

        arcpy.AddMessage(prjFile + "\n")
        sr = arcpy.SpatialReference(prjFile)
        df.spatialReference = sr
        arcpy.RefreshActiveView()
        
    elif int(arcpy.management.GetCount(lyr).getOutput(0)) > 1:
        zone_lyr = arcpy.mapping.Layer(data_dir + os.sep + "zones.lyr")
        zone_lyr.replaceDataSource(data_dir, "NONE", "usstpln83")
        zone_lyr.name = "stateplane"
        arcpy.mapping.AddLayer(df, zone_lyr)
        arcpy.AddMessage("\nYou are looking at more than one State Plane "\
                         "zone right now.  Zone boundaries have been added to "\
                         "the display.  Pick one, zoom in, and rerun tool.\n")
    else:
        zone_lyr = arcpy.mapping.Layer(data_dir + os.sep + "zones.lyr")
        zone_lyr.replaceDataSource(data_dir, "NONE", "usstpln83")
        zone_lyr.name = "stateplane"
        arcpy.mapping.AddLayer(df, zone_lyr)
        arcpy.AddMessage("\nSome issue with the zone selection process,"\
                         " perhaps you are looking at the ocean."\
                         "  Zone boundaries have been added to "\
                         "the display.  Pick one, zoom in, and rerun tool.\n")
    
except:
    arcpy.AddMessage("\nERROR: You probably need to close an edit session.\n")
